# Case Style Changer

[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/xkumiyu/case-style-changer/Python%20package)](https://github.com/xkumiyu/case-style-changer/actions) [![codecov](https://img.shields.io/codecov/c/github/xkumiyu/case-style-changer)](https://codecov.io/gh/xkumiyu/case-style-changer) [![Code Climate](https://img.shields.io/codeclimate/maintainability/xkumiyu/case-style-changer)](https://codeclimate.com/github/xkumiyu/case-style-changer) [![License](https://img.shields.io/github/license/xkumiyu/case-style-changer)](LICENSE)

[![PyPi](https://img.shields.io/pypi/v/case-style-changer)]()

Case Style Changer is a CLI tool that guesses the case of the input string and converts it to another case.

## Installation

``` sh
pip install case-style-changer
```

## Usage

``` sh
$ csc [--text TEXT] CASE_NAME
```

`CASE_NAME` is the name of the case you want to convert.

### Examples

You can use standard input or arguments.

``` sh
$ echo "case-style-changer" | csc camel_case
caseStyleChanger
```

``` sh
$ csc snake_case --text "caseStyleChanger"
case_style_changer
```

### Available case style

| Case Name | Example |
|:--:|:--:|
| `camel_case` | caseStyleChanger |
| `pascal_case` | CaseStyleChanger |
| `snake_case` | case_style_changer |
| `constant_case` | CASE_STYLE_CHANGER |
| `kebab_case` | case-style-changer |
